@@ -139,6 +139,16 @@ class AssignmentClause(BaseClause):
         return self.field, self.context_id
 
 
+class TransactionClause(BaseClause):
+    """ A single variable iff statement """
+
+    def __unicode__(self):
+        return u'"{}" = %({})s'.format(self.field, self.context_id)
+
+    def insert_tuple(self):
+        return self.field, self.context_id
+
+
 class ContainerUpdateClause(AssignmentClause):
 
     def __init__(self, field, value, operation=None, previous=None, column=None):
@@ -173,15 +183,18 @@ class SetUpdateClause(ContainerUpdateClause):
     def __unicode__(self):
         qs = []
         ctx_id = self.context_id
-        if self.previous is None and not (self._assignments or self._additions or self._removals):
+        if (self.previous is None and
+                self._assignments is None and
+                self._additions is None and
+                self._removals is None):
             qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
-        if self._assignments:
+        if self._assignments is not None:
             qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
             ctx_id += 1
-        if self._additions:
+        if self._additions is not None:
             qs += ['"{0}" = "{0}" + %({1})s'.format(self.field, ctx_id)]
             ctx_id += 1
-        if self._removals:
+        if self._removals is not None:
             qs += ['"{0}" = "{0}" - %({1})s'.format(self.field, ctx_id)]
 
         return ', '.join(qs)
@@ -204,22 +217,28 @@ class SetUpdateClause(ContainerUpdateClause):
 
     def get_context_size(self):
         if not self._analyzed: self._analyze()
-        if self.previous is None and not (self._assignments or self._additions or self._removals):
+        if (self.previous is None and
+                self._assignments is None and
+                self._additions is None and
+                self._removals is None):
             return 1
         return int(bool(self._assignments)) + int(bool(self._additions)) + int(bool(self._removals))
 
     def update_context(self, ctx):
         if not self._analyzed: self._analyze()
         ctx_id = self.context_id
-        if self.previous is None and not (self._assignments or self._additions or self._removals):
+        if (self.previous is None and
+                self._assignments is None and
+                self._additions is None and
+                self._removals is None):
             ctx[str(ctx_id)] = self._to_database({})
-        if self._assignments:
+        if self._assignments is not None:
             ctx[str(ctx_id)] = self._to_database(self._assignments)
             ctx_id += 1
-        if self._additions:
+        if self._additions is not None:
             ctx[str(ctx_id)] = self._to_database(self._additions)
             ctx_id += 1
-        if self._removals:
+        if self._removals is not None:
             ctx[str(ctx_id)] = self._to_database(self._removals)
 
 
@@ -239,11 +258,11 @@ class ListUpdateClause(ContainerUpdateClause):
             qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
             ctx_id += 1
 
-        if self._prepend:
+        if self._prepend is not None:
             qs += ['"{0}" = %({1})s + "{0}"'.format(self.field, ctx_id)]
             ctx_id += 1
 
-        if self._append:
+        if self._append is not None:
             qs += ['"{0}" = "{0}" + %({1})s'.format(self.field, ctx_id)]
 
         return ', '.join(qs)
@@ -258,13 +277,13 @@ class ListUpdateClause(ContainerUpdateClause):
         if self._assignments is not None:
             ctx[str(ctx_id)] = self._to_database(self._assignments)
             ctx_id += 1
-        if self._prepend:
+        if self._prepend is not None:
             # CQL seems to prepend element at a time, starting
             # with the element at idx 0, we can either reverse
             # it here, or have it inserted in reverse
             ctx[str(ctx_id)] = self._to_database(list(reversed(self._prepend)))
             ctx_id += 1
-        if self._append:
+        if self._append is not None:
             ctx[str(ctx_id)] = self._to_database(self._append)
 
     def _analyze(self):
@@ -359,7 +378,7 @@ class MapUpdateClause(ContainerUpdateClause):
 
         ctx_id = self.context_id
         if self.previous is None and not self._updates:
-            qs += ['"int_map" = %({})s'.format(ctx_id)]
+            qs += ['"{}" = %({})s'.format(self.field, ctx_id)]
         else:
             for _ in self._updates or []:
                 qs += ['"{}"[%({})s] = %({})s'.format(self.field, ctx_id, ctx_id + 1)]
@@ -666,6 +685,26 @@ class InsertStatement(AssignmentStatement):
 class UpdateStatement(AssignmentStatement):
     """ an cql update select statement """
 
+    def __init__(self,
+                 table,
+                 assignments=None,
+                 consistency=None,
+                 where=None,
+                 ttl=None,
+                 timestamp=None,
+                 transactions=None):
+        super(UpdateStatement, self). __init__(table,
+                                               assignments=assignments,
+                                               consistency=consistency,
+                                               where=where,
+                                               ttl=ttl,
+                                               timestamp=timestamp)
+
+        # Add iff statements
+        self.transactions = []
+        for transaction in transactions or []:
+            self.add_transaction_clause(transaction)
+
     def __unicode__(self):
         qs = ['UPDATE', self.table]
 
@@ -686,8 +725,39 @@ class UpdateStatement(AssignmentStatement):
         if self.where_clauses:
             qs += [self._where]
 
+        if len(self.transactions) > 0:
+            qs += [self._get_transactions()]
+
         return ' '.join(qs)
 
+    def add_transaction_clause(self, clause):
+        """
+        Adds a iff clause to this statement
+
+        :param clause: The clause that will be added to the iff statement
+        :type clause: TransactionClause
+        """
+        if not isinstance(clause, TransactionClause):
+            raise StatementException('only instances of AssignmentClause can be added to statements')
+        clause.set_context_id(self.context_counter)
+        self.context_counter += clause.get_context_size()
+        self.transactions.append(clause)
+
+    def get_context(self):
+        ctx = super(UpdateStatement, self).get_context()
+        for clause in self.transactions or []:
+            clause.update_context(ctx)
+        return ctx
+
+    def _get_transactions(self):
+        return 'IF {}'.format(' AND '.join([six.text_type(c) for c in self.transactions]))
+
+    def update_context_id(self, i):
+        super(UpdateStatement, self).update_context_id(i)
+        for transaction in self.transactions:
+            transaction.set_context_id(self.context_counter)
+            self.context_counter += transaction.get_context_size()
+
 
 class DeleteStatement(BaseCQLStatement):
     """ a cql delete statement """
