@@ -30,8 +30,6 @@ from cqlengine.columns import Inet
 from cqlengine.management import sync_table, drop_table
 from cqlengine.models import Model
 
-import sys
-
 
 class TestDatetime(BaseCassEngTestCase):
     class DatetimeTest(Model):
@@ -99,7 +97,22 @@ class TestBoolDefault(BaseCassEngTestCase):
         tmp2 = self.BoolDefaultValueTest.get(test_id=1)
         self.assertEqual(True, tmp2.stuff)
 
+class TestBoolValidation(BaseCassEngTestCase):
+    class BoolValidationTest(Model):
+        __keyspace__ = 'test'
+        test_id = Integer(primary_key=True)
+        bool_column = Boolean()
 
+    @classmethod
+    def setUpClass(cls):
+        super(TestBoolValidation, cls).setUpClass()
+        sync_table(cls.BoolValidationTest)
+
+    def test_validation_preserves_none(self):
+        test_obj = self.BoolValidationTest(test_id=1)
+
+        test_obj.validate()
+        self.assertIsNone(test_obj.bool_column)
 
 class TestVarInt(BaseCassEngTestCase):
     class VarIntTest(Model):
