@@ -4,13 +4,14 @@ from uuid import uuid4
 from cqlengine.tests.base import BaseCassEngTestCase
 
 from cqlengine.exceptions import ModelException
-from cqlengine.management import create_table
-from cqlengine.management import delete_table
+from cqlengine.management import sync_table
+from cqlengine.management import drop_table
 from cqlengine.models import Model
 from cqlengine import columns
 from cqlengine import query
 
 class DateTimeQueryTestModel(Model):
+    __keyspace__ = 'test'
     user        = columns.Integer(primary_key=True)
     day         = columns.DateTime(primary_key=True)
     data        = columns.Text()
@@ -20,7 +21,7 @@ class TestDateTimeQueries(BaseCassEngTestCase):
     @classmethod
     def setUpClass(cls):
         super(TestDateTimeQueries, cls).setUpClass()
-        create_table(DateTimeQueryTestModel)
+        sync_table(DateTimeQueryTestModel)
 
         cls.base_date = datetime.now() - timedelta(days=10)
         for x in range(7):
@@ -35,7 +36,7 @@ class TestDateTimeQueries(BaseCassEngTestCase):
     @classmethod
     def tearDownClass(cls):
         super(TestDateTimeQueries, cls).tearDownClass()
-        delete_table(DateTimeQueryTestModel)
+        drop_table(DateTimeQueryTestModel)
 
     def test_range_query(self):
         """ Tests that loading from a range of dates works properly """
