@@ -1,7 +1,7 @@
 from unittest import TestCase
 from cqlengine.statements import DeleteStatement, WhereClause, MapDeleteClause
 from cqlengine.operators import *
-
+import six
 
 class DeleteStatementTests(TestCase):
 
@@ -14,24 +14,24 @@ class DeleteStatementTests(TestCase):
     def test_field_rendering(self):
         """ tests that fields are properly added to the select statement """
         ds = DeleteStatement('table', ['f1', 'f2'])
-        self.assertTrue(unicode(ds).startswith('DELETE "f1", "f2"'), unicode(ds))
+        self.assertTrue(six.text_type(ds).startswith('DELETE "f1", "f2"'), six.text_type(ds))
         self.assertTrue(str(ds).startswith('DELETE "f1", "f2"'), str(ds))
 
     def test_none_fields_rendering(self):
         """ tests that a '*' is added if no fields are passed in """
         ds = DeleteStatement('table', None)
-        self.assertTrue(unicode(ds).startswith('DELETE FROM'), unicode(ds))
+        self.assertTrue(six.text_type(ds).startswith('DELETE FROM'), six.text_type(ds))
         self.assertTrue(str(ds).startswith('DELETE FROM'), str(ds))
 
     def test_table_rendering(self):
         ds = DeleteStatement('table', None)
-        self.assertTrue(unicode(ds).startswith('DELETE FROM table'), unicode(ds))
+        self.assertTrue(six.text_type(ds).startswith('DELETE FROM table'), six.text_type(ds))
         self.assertTrue(str(ds).startswith('DELETE FROM table'), str(ds))
 
     def test_where_clause_rendering(self):
         ds = DeleteStatement('table', None)
         ds.add_where_clause(WhereClause('a', EqualsOperator(), 'b'))
-        self.assertEqual(unicode(ds), 'DELETE FROM table WHERE "a" = %(0)s', unicode(ds))
+        self.assertEqual(six.text_type(ds), 'DELETE FROM table WHERE "a" = %(0)s', six.text_type(ds))
 
     def test_context_update(self):
         ds = DeleteStatement('table', None)
@@ -39,7 +39,7 @@ class DeleteStatementTests(TestCase):
         ds.add_where_clause(WhereClause('a', EqualsOperator(), 'b'))
 
         ds.update_context_id(7)
-        self.assertEqual(unicode(ds), 'DELETE "d"[%(8)s] FROM table WHERE "a" = %(7)s')
+        self.assertEqual(six.text_type(ds), 'DELETE "d"[%(8)s] FROM table WHERE "a" = %(7)s')
         self.assertEqual(ds.get_context(), {'7': 'b', '8': 3})
 
     def test_context(self):
